@@ -165,9 +165,9 @@ class KubeModel(ABC):
         """
         job_id = self.args._job_id
         func_id = self.args._func_id
-        self.logger.debug('loading file to host')
+        self.logger.debug('loading file from host')
 
-        with open(f'/output/{job_id}:test:{func_id}.pkl', 'wb') as f:
+        with open(f'/output/{job_id}:test:{func_id}.pkl', 'rb') as f:
             self.logger.debug(f'loading file, epoch: {self.epoch}')
             state = pickle.load(f)
             self.logger.debug(f'file loaded, value: {state}')
